@@ -283,6 +283,17 @@ solaris_mode_toggled(GtkToggleButton *button, gpointer data)
 }
 
 
+static void
+network_in_bits_toggled(GtkToggleButton *button, gpointer data)
+{
+	ProcData *procdata = static_cast<ProcData*>(data);
+	GConfClient *client = procdata->client;
+	gboolean toggled;
+	toggled = gtk_toggle_button_get_active(button);
+	gconf_client_set_bool(client, procman::gconf::network_in_bits.c_str(), toggled, NULL);
+}
+
+
 
 static void
 smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
@@ -668,6 +679,18 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
 	
+
+	GtkWidget *bits_button;
+	bits_button = gtk_check_button_new_with_mnemonic(_("Show network speed in bits"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bits_button),
+				     gconf_client_get_bool(procdata->client,
+							   procman::gconf::network_in_bits.c_str(),
+							   NULL));
+	g_signal_connect(G_OBJECT(bits_button), "toggled",
+			 G_CALLBACK(network_in_bits_toggled), procdata);
+	gtk_box_pack_start(GTK_BOX(vbox2), bits_button, TRUE, TRUE, 0);
+
+
 	
 	hbox2 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, TRUE, 0);
