@@ -1,9 +1,9 @@
 #ifndef H_GNOME_SYSTEM_MONITOR_SYSINFO_H_1155594649
 #define H_GNOME_SYSTEM_MONITOR_SYSINFO_H_1155594649
 
-#include <gtk/gtk.h>
-
-GtkWidget *
-procman_create_sysinfo_view(void);
+namespace procman
+{
+  void build_sysinfo_ui();
+}
 
 #endif /* H_GNOME_SYSTEM_MONITOR_SYSINFO_H_1155594649 */
